from typing import Any
from dataclasses import dataclass


@dataclass(slots=True)
class USBCameraConfig:
    device_index: int = 0
    format: str = "MJPG"
    width: int = 640
    height: int = 480
    fps: int = 30

    auto_exposure: bool = True
    exposure: float = 0.0
    gain: float = 0.0

    auto_focus: bool = True
    focus: float = 0.0

    auto_white_balance: bool = True
    white_balance_temperature: float = 0.0

    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> "USBCameraConfig":
        return cls(
            device_index=data.get("device_index", 0),
            format=data.get("format", "MJPG"),
            width=data.get("width", 640),
            height=data.get("height", 480),
            fps=data.get("fps", 30),
            auto_exposure=data.get("auto_exposure", True),
            exposure=data.get("exposure", 0.0),
            gain=data.get("gain", 0.0),
            auto_focus=data.get("auto_focus", True),
            focus=data.get("focus", 0.0),
            auto_white_balance=data.get("auto_white_balance", True),
            white_balance_temperature=data.get("white_balance_temperature", 0.0),
        )



from typing import Any
from dataclasses import dataclass


@dataclass(slots=True)
class W1BusConfig:
    base_path: str = "/sys/bus/w1/devices"

    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> "W1BusConfig":
        return cls(base_path=data.get("base_path", "/sys/bus/w1/devices"))



from typing import Any
from dataclasses import dataclass


@dataclass(slots=True)
class NAU7802CalibrationConfig:
    offset: int = 0
    scale: float = 1.0

    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> "NAU7802CalibrationConfig":
        return cls(
            offset=data.get("offset", 0),
            scale=data.get("scale", 1.0),
        )


@dataclass(slots=True)
class NAU7802ChannelConfig:
    calibration: NAU7802CalibrationConfig

    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> "NAU7802ChannelConfig":
        return cls(
            calibration=NAU7802CalibrationConfig.from_dict(data.get("calibration", {}))
        )


@dataclass(slots=True)
class NAU7802Config:
    bus_id: str
    channels: dict[str, NAU7802ChannelConfig]
    addr: int = 0x2A

    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> "NAU7802Config":
        channels = {
            str(k): NAU7802ChannelConfig.from_dict(v)
            for k, v in data.get("channels", {}).items()
        }

        return cls(
            bus_id=data["bus_id"],
            addr=data.get("addr", 0x2A),
            channels=channels,
        )



from typing import Any
from dataclasses import dataclass


@dataclass(slots=True)
class PumpConfig:
    pin: int

    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> "PumpConfig":
        return cls(pin=data["pin"])



from typing import Any
from dataclasses import dataclass


@dataclass(slots=True)
class I2CBusConfig:
    bus: int = 1

    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> "I2CBusConfig":
        return cls(bus=data.get("bus", 1))



from typing import Any
from dataclasses import dataclass


@dataclass(slots=True)
class DS18B20Config:
    bus_id: str
    device_id: str

    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> "DS18B20Config":
        return cls(bus_id=data["bus_id"], device_id=data["device_id"])
